@@ -2,13 +2,13 @@
 
 import click
 from sam2lca import __version__
-from sam2lca.main import sam2lca
+from sam2lca.main import sam2lca, update_database
 from pathlib import Path
 
 
-@click.command()
+@click.group()
 @click.version_option(__version__)
-@click.argument('sam', type=click.Path(exists=True))
+@click.pass_context
 @click.option('-m',
               '--mappings',
               type=click.Choice(['nucl',
@@ -18,6 +18,30 @@ from pathlib import Path
               default='nucl',
               show_default=True,
               help='Mapping type of accession to TAXID')
+@click.option('-d',
+              '--dbdir',
+              type=click.Path(writable=True,
+                              dir_okay=True, file_okay=False),
+              default=f"{str(Path.home())}/.sam2lca",
+              show_default=True,
+              help='Directory to store taxonomy databases')
+def cli(ctx, mappings, dbdir):
+    """\b
+    sam2lca: Last Common Ancestor on SAM/BAM/CRAM alignment files
+    Author: Maxime Borry
+    Contact: <borry[at]shh.mpg.de>
+    Homepage & Documentation: github.com/maxibor/sam2lca
+    """
+    ctx.ensure_object(dict)
+
+    ctx.obj['mappings'] = mappings
+    ctx.obj['dbdir'] = dbdir
+    pass
+
+
+@cli.command()
+@click.pass_context
+@click.argument('sam', type=click.Path(exists=True))
 @click.option('-i',
               '--identity',
               type=float,
@@ -36,37 +60,33 @@ from pathlib import Path
               default=2,
               show_default=True,
               help='Number of process for parallelization')
-@click.option('-u',
-              '--update',
-              is_flag=True,
-              help='Update local copy of NCBI taxonomy database')
 @click.option('-t',
               '--tree',
               type=click.Path(exists=True),
               help='Optional Newick Taxonomy Tree')
-@click.option('-d',
-              '--dbdir',
-              type=click.Path(writable=True,
-                              dir_okay=True, file_okay=False),
-              default=f"{str(Path.home())}/.sam2lca",
-              show_default=True,
-              help='Directory to store taxonomy databases')
 @click.option('-o',
               '--output',
               type=click.Path(writable=True, dir_okay=False, file_okay=True),
               default=None,
               help='sam2lca output file')
-def cli(no_args_is_help=True, **kwargs):
+def analyze(ctx, no_args_is_help=True, **kwargs):
     """\b
-    sam2lca: Last Common Ancestor on SAM/BAM/CRAM alignment files
-    Author: Maxime Borry
-    Contact: <borry[at]shh.mpg.de>
-    Homepage & Documentation: github.com/maxibor/sam2lca
+    Run the sam2lca analysis
 
     SAM: path to SAM/BAM/CRAM alignment file
     """
-    sam2lca(**kwargs)
+    sam2lca(**kwargs, **ctx.obj)
 
+@cli.command()
+@click.pass_context
+@click.option("-n",
+              "--ncbi",
+              is_flag=True,
+              help="Update NCBI taxonomy tree")
+def update_db(ctx, no_args_is_help=True, **kwargs):
+    """Download/prepare mappings and taxonomy databases
+    """
+    update_database(**ctx.obj, **kwargs)
 
 if __name__ == "__main__":
     cli()
